Crate future_utils [−] [src]
Modules
| mpsc |
channels in the futures-rs crate cannot error, yet they return () for their error type for some stupid reason. This is a wrapper around futures-rs unbounded channels which removes the error. |
Structs
| DropNotice |
Created in tandem with a |
| DropNotify |
Created in tandem with a |
| Infallible |
Wraps a future or stream which can't fail (ie. has error type |
| LogErrors |
Removes the errors from a stream and logs them. |
| NextOrElse | |
| Until |
Runs a stream or future until some condition is met. |
Traits
| FutureExt |
Extension trait for |
| StreamExt |
Extension trait for |
Functions
| drop_notify |
Create a ( |
Type Definitions
| BoxFuture | |
| BoxSink | |
| BoxStream | |
| IoFuture | |
| IoSink | |
| IoStream |